@@ -99,7 +99,8 @@ class Domoticz(IPlugin):
 				log.msg("resp  :  %s" % (resp))
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				for xx in jsonreq['result'].length:
+				len = len(jsonreq['result'])
+				for xx in len:
 					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
 					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
 		if bodies == "":
